[Checkins] SVN: zc.ngi/trunk/src/zc/ngi/ More spelling fixes.

Amos Latteier amos at latteier.com
Wed Dec 20 10:34:26 EST 2006


Log message for revision 71620:
  More spelling fixes.
  

Changed:
  U   zc.ngi/trunk/src/zc/ngi/README.txt
  U   zc.ngi/trunk/src/zc/ngi/adapters.txt
  U   zc.ngi/trunk/src/zc/ngi/interfaces.py

-=-
Modified: zc.ngi/trunk/src/zc/ngi/README.txt
===================================================================
--- zc.ngi/trunk/src/zc/ngi/README.txt	2006-12-20 15:18:10 UTC (rev 71619)
+++ zc.ngi/trunk/src/zc/ngi/README.txt	2006-12-20 15:34:26 UTC (rev 71620)
@@ -28,7 +28,7 @@
     connections.
 
 IListener
-    Listed for incoming connections.
+    Listen for incoming connections.
 
 IServer
     Callback to handle incoming connections.

Modified: zc.ngi/trunk/src/zc/ngi/adapters.txt
===================================================================
--- zc.ngi/trunk/src/zc/ngi/adapters.txt	2006-12-20 15:18:10 UTC (rev 71619)
+++ zc.ngi/trunk/src/zc/ngi/adapters.txt	2006-12-20 15:34:26 UTC (rev 71620)
@@ -3,9 +3,9 @@
 ============
 
 The NGI is a fairly low-level event-based framework.  Adapters can be
-used to build higher-level sematics.  In this document, we'll describe
+used to build higher-level semantics.  In this document, we'll describe
 some sample adapters that provide more examples of using the NGI and
-useful building blocks for other applications. The sound for these
+useful building blocks for other applications. The source for these
 adapters can be found in the zc.ngi.adapters module.
 
 Lines
@@ -48,7 +48,7 @@
     -> 'World!'
 
 Only input handling is affected.  Other methods of the adapter behave
-as would the underlying connnection:
+as would the underlying connection:
 
     >>> adapter.write('foo')
     -> 'foo'
@@ -90,7 +90,7 @@
 
 Here we saw that our handler got the two messages individually.
 
-If we write a message, we can see that the message is preceeded by the
+If we write a message, we can see that the message is preceded by the
 message size:
 
     >>> adapter.write(message1) 
@@ -101,7 +101,7 @@
 -------------
 
 It can be useful to send Null messages to make sure that a client is
-still connected.  The sized adapter supprts such messages.  Calling
+still connected.  The sized adapter supports such messages.  Calling
 write with None, sends a null message, which is a message with a
 length of 1 << 32 - 1 and no message data:
 

Modified: zc.ngi/trunk/src/zc/ngi/interfaces.py
===================================================================
--- zc.ngi/trunk/src/zc/ngi/interfaces.py	2006-12-20 15:18:10 UTC (rev 71619)
+++ zc.ngi/trunk/src/zc/ngi/interfaces.py	2006-12-20 15:34:26 UTC (rev 71620)
@@ -22,7 +22,7 @@
 register handlers that respond to input events.  There are 3 kinds of
 handlers:
 
-- Input handlers recieve network input
+- Input handlers receive network input
 
 - Client-connect handlers respond to outbound connection events, and
 
@@ -31,8 +31,8 @@
 The interfaces are designed to allow single-threaded applications:
 
 - An implementation of the interfaces is not allowed to make multiple
-  simultanious calls to the same application handler.  (Note that this
-  requirement does not extend accross multiple implementations.
+  simultaneous calls to the same application handler.  (Note that this
+  requirement does not extend across multiple implementations.
   Theoretically, different implementations could call handlers at the
   same time.
 
@@ -67,7 +67,7 @@
     def setHandler(handler):
         """Set the IConnectionHandler for a connection.
 
-        This methid can only be called in direct response to an
+        This method can only be called in direct response to an
         implementation call to a IConnectionHandler,
         IClientConnectHandler, or IServer
         """
@@ -90,7 +90,7 @@
     """Objects that can handle connection input-data events
 
     The methods defined be this interface will never be called
-    simultaniously from separate threads, so implementation of the
+    simultaneously from separate threads, so implementation of the
     methods needn't be concerned with thread safety with respect to
     these methods.
     """
@@ -100,15 +100,15 @@
         
         The data is an 8-bit string.
 
-        Note that there are no promises about blocking.  There data
+        Note that there are no promises about blocking.  The data
         isn't necessarily record oriented.  For example, data could,
-        in theory be passed one character at a time.  It os up to
+        in theory be passed one character at a time.  It is up to
         applications to organize data into records, if desired.
         
         """
 
     def handle_close(connection, reason):
         """Recieve notification that a connection has closed
         
         The reason argument can be converted to a string for logging
         purposes.  It may have data useful for debugging, but this
@@ -130,20 +130,20 @@
         
         The handler is an IClientConnectHandler.  The handler
         connected method will be called with an IConnection object
-        if and when the connection suceeds or failed_connect method
+        if and when the connection succeeds or failed_connect method
         will be called if the connection fails.
         """
 
 class IClientConnectHandler(Interface):
     """Recieve notifications of connection results
     """
 
     def connected(connection):
         """Recieve notification that a connection had been established
         """
         
     def failed_connect(reason):
         """Recieve notificantion that a connection could not be established
 
         The reason argument can be converted to a string for logging
         purposes.  It may have data useful for debugging, but this
@@ -157,7 +157,7 @@
     def __call__(address, handler):
         """Listen for incoming connections
 
-        When a connection is recieved, call the handler.
+        When a connection is received, call the handler.
 
         An IServerControl object is returned.
         """
@@ -179,9 +179,9 @@
         """
 
     def close(handler=None):
-        """Close the listener and all of it's connections
+        """Close the listener and all of its connections
 
-        If no handler is passed, the listener and it's connections
+        If no handler is passed, the listener and its connections
         are closed immediately without waiting for any pending input
         to be handled or for pending output to be sent.
 
@@ -100,15 +100,15 @@
 
     def handle_close(connection, reason):
-        """Recieve notification that a connection has closed
+        """Receive notification that a connection has closed
         
         The reason argument can be converted to a string for logging
@@ -130,20 +130,20 @@
 
 class IClientConnectHandler(Interface):
-    """Recieve notifications of connection results
+    """Receive notifications of connection results
     """
 
@@ -130,20 +130,20 @@
 
     def connected(connection):
-        """Recieve notification that a connection had been established
+        """Receive notification that a connection had been established
         """
         
@@ -130,20 +130,20 @@
         
     def failed_connect(reason):
-        """Recieve notificantion that a connection could not be established
+        """Receive notification that a connection could not be established
 
         The reason argument can be converted to a string for logging



More information about the Checkins mailing list